@@ -910,6 +910,23 @@ sub ProcessFreeGPS($$$)
             map { $_ = $_ - 4294967296 if $_ >= 0x80000000; $_ /= 256 } @acc;
         }
 
+    } elsif ($$dataPt =~ /^.{40}A([NS])([EW])/s) {
+
+        # decode freeGPS from ViofoA119v3 dashcam (similar to Novatek GPS format)
+        # 0000: 00 00 40 00 66 72 65 65 47 50 53 20 f0 03 00 00 [..@.freeGPS ....]
+        # 0010: 05 00 00 00 2f 00 00 00 03 00 00 00 13 00 00 00 [..../...........]
+        # 0020: 09 00 00 00 1b 00 00 00 41 4e 57 00 25 d1 99 45 [........ANW.%..E]
+        # 0030: f1 47 40 46 66 66 d2 41 85 eb 83 41 00 00 00 00 [.G@Fff.A...A....]
+        ($latRef, $lonRef) = ($1, $2);
+        ($hr,$min,$sec,$yr,$mon,$day) = unpack('x16V6', $$dataPt);
+        $yr += 2000;
+        SetByteOrder('II');
+        $lat = GetFloat($dataPt, 0x2c);
+        $lon = GetFloat($dataPt, 0x30);
+        $spd = GetFloat($dataPt, 0x34) * 1.852; # (convert knots to km/h)
+        $trk = GetFloat($dataPt, 0x38);
+        SetByteOrder('MM');
+
     } else {
 
         # decode binary GPS format (Viofo A119S, ref 2)
@@ -1482,14 +1499,15 @@ sub ProcessNMEA($$$)
 {
     my ($et, $dirInfo, $tagTbl) = @_;
     my $dataPt = $$dirInfo{DataPt};
-    # parse only RMC sentence for now, and ignore leading timestamps (ms since 1970)
-    while ($$dataPt =~ /\$[A-Z]{2}RMC,(\d{2})(\d{2})(\d+(\.\d*)?),A?,(\d+\.\d+),([NS]),(\d+\.\d+),([EW]),(\d*\.?\d*),(\d*\.?\d*),(\d{2})(\d{2})(\d+)/g) {
-        my ($lat,$latRef,$lon,$lonRef) = ($5,$6,$7,$8);
-        my $yr = $13 + ($13 >= 70 ? 1900 : 2000);
-        my ($mon,$day,$hr,$min,$sec) = ($12,$11,$1,$2,$3);
+    # parse only RMC sentence (with leading timestamp) for now
+    while ($$dataPt =~ /(?:\[(\d+)\])?\$[A-Z]{2}RMC,(\d{2})(\d{2})(\d+(\.\d*)?),A?,(\d+\.\d+),([NS]),(\d+\.\d+),([EW]),(\d*\.?\d*),(\d*\.?\d*),(\d{2})(\d{2})(\d+)/g) {
+        my $tc = $1;    # milliseconds since 1970 (local time)
+        my ($lat,$latRef,$lon,$lonRef) = ($6,$7,$8,$9);
+        my $yr = $14 + ($14 >= 70 ? 1900 : 2000);
+        my ($mon,$day,$hr,$min,$sec) = ($13,$12,$2,$3,$4);
         my ($spd, $trk);
-        $spd = $9 * $knotsToKph if length $9;
-        $trk = $10 if length $10;
+        $spd = $10 * $knotsToKph if length $10;
+        $trk = $11 if length $11;
         # lat/long are in DDDMM.MMMM format
         my $deg = int($lat / 100);
         $lat = $deg + ($lat - $deg * 100) / 60;
@@ -1497,7 +1515,9 @@ sub ProcessNMEA($$$)
         $lon = $deg + ($lon - $deg * 100) / 60;
         $sec = '0' . $sec unless $sec =~ /^\d{2}/;   # pad integer part of seconds to 2 digits
         my $time = sprintf('%.4d:%.2d:%.2d %.2d:%.2d:%sZ',$yr,$mon,$day,$hr,$min,$sec);
-        $$et{DOC_NUM} = ++$$et{DOC_COUNT};
+        my $sampleTime;
+        $sampleTime = ($tc - $$et{StartTime}) / 1000 if $tc and $$et{StartTime};
+        FoundSomething($et, $tagTbl, $sampleTime);
         $et->HandleTag($tagTbl, GPSDateTime => $time);
         $et->HandleTag($tagTbl, GPSLatitude  => $lat * ($latRef eq 'S' ? -1 : 1));
         $et->HandleTag($tagTbl, GPSLongitude => $lon * ($lonRef eq 'W' ? -1 : 1));
@@ -1689,8 +1709,8 @@ sub ProcessINSVTrailer($)
                                 ($a[7] eq 'E' or $a[7] eq 'W');
                     $$et{DOC_NUM} = ++$$et{DOC_COUNT};
                     $a[$_] = GetDouble(\$a[$_], 0) foreach 4,6,8,9,10;
-                    $a[4] *= -abs($a[4]) if $a[5] eq 'S'; # (abs just in case it was already signed)
-                    $a[6] *= -abs($a[6]) if $a[7] eq 'W';
+                    $a[4] = -abs($a[4]) if $a[5] eq 'S'; # (abs just in case it was already signed)
+                    $a[6] = -abs($a[6]) if $a[7] eq 'W';
                     $et->HandleTag($tagTbl, GPSDateTime => Image::ExifTool::ConvertUnixTime($a[0]) . 'Z');
                     $et->HandleTag($tagTbl, GPSLatitude => $a[4]);
                     $et->HandleTag($tagTbl, GPSLongitude => $a[6]);
